@@ -14,7 +14,7 @@ import ..Tokens: AbstractToken, Token, RawToken, Kind, TokenError, UNICODE_OPS,
 import ..Tokens: FUNCTION, ABSTRACT, IDENTIFIER, BAREMODULE, BEGIN, BREAK, CATCH, CONST, CONTINUE,
                  DO, ELSE, ELSEIF, END, EXPORT, FALSE, FINALLY, FOR, FUNCTION, GLOBAL, LET, LOCAL, IF,
                  IMPORT, IMPORTALL, MACRO, MODULE, OUTER, QUOTE, RETURN, TRUE, TRY, TYPE, USING, WHILE, ISA, IN,
-                 MUTABLE, PRIMITIVE, STRUCT, WHERE
+                 MUTABLE, PRIMITIVE, PUBLIC, STRUCT, WHERE
 
 
 export tokenize
@@ -629,12 +629,13 @@ function lex_digit(l::Lexer, kind)
     accept_number(l, isdigit)
     pc,ppc = dpeekchar(l)
     if pc == '.'
-        if kind === Tokens.FLOAT
+        if ppc == '.'
+            # Number followed by .. or ...
+            return emit(l, kind)
+        elseif kind === Tokens.FLOAT
             # If we enter the function with kind == FLOAT then a '.' has been parsed.
             readchar(l)
             return emit_error(l, Tokens.INVALID_NUMERIC_CONSTANT)
-        elseif ppc == '.'
-            return emit(l, kind)
         elseif is_operator_start_char(ppc) && ppc !== ':'
             readchar(l)
             return emit_error(l)
@@ -703,7 +704,9 @@ function lex_digit(l::Lexer, kind)
             readchar(l)
             !(ishex(ppc) || ppc == '.') && return emit_error(l, Tokens.INVALID_NUMERIC_CONSTANT)
             accept_number(l, ishex)
-            if accept(l, '.')
+            pc,ppc = dpeekchar(l)
+            if pc == '.' && ppc != '.'
+                readchar(l)
                 accept_number(l, ishex)
                 isfloat = true
             end
@@ -1090,6 +1093,7 @@ Tokens.MODULE,
 Tokens.MUTABLE,
 Tokens.OUTER,
 Tokens.PRIMITIVE,
+Tokens.PUBLIC,
 Tokens.QUOTE,
 Tokens.RETURN,
 Tokens.STRUCT,
